@@ -39,7 +39,7 @@ sub run {
         print "… by hitting ENTER now.$/";
         <>;
 
-        my $created = $acme->create_new_account(
+        my $created = $acme->create_account(
             termsOfServiceAgreed => 1,
         );
     }
@@ -112,9 +112,9 @@ sub run {
 
     print "Certificate key:$/$key$/$/";
 
-    print "$/Certificate URL: " . $order->certificate() . $/ . $/;
+    print "Certificate chain:$/$/";
 
-    print HTTP::Tiny->new()->get($order->certificate())->{'content'};
+    print $acme->get_certificate_chain($order);
 
     return;
 }
